==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/db/DBIdentityTypes.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Nov 30, 2009
 * Author: T. Rekawek <newton@mat.uni.torun.pl>
 */

package pl.edu.icm.unicore.uvos.db;

import java.util.Hashtable;
import java.util.List;
import java.util.Vector;

import org.apache.ibatis.exceptions.PersistenceException;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.UnsupportedTypeException;
import pl.edu.icm.unicore.uvos.model.IdentityTypeBean;

/**
 * DB operations related to identity types.
 * @author T. Rekawek
 */
public class DBIdentityTypes
{
	private static final Logger log = Logger.getLogger(DBIdentityTypes.class);
	private Hashtable<String, IdentityTypeBean> identityTypes;
	private Hashtable<Integer, IdentityType> identityTypes2;
	private Vector<IdentityType> identityTypesL;
	
	public DBIdentityTypes(DB db) throws InternalException
	{
		SqlSession sqlMap = db.getSqlSession();

		identityTypes = new Hashtable<String, IdentityTypeBean>();
		identityTypes2 = new Hashtable<Integer, IdentityType>();
		identityTypesL = new Vector<IdentityType>();
		try
		{
			List<?> idTypes = sqlMap.selectList("getAllIdentityTypes");
			for (Object o: idTypes)
			{
				IdentityTypeBean ib = (IdentityTypeBean)o;
				IdentityType it = new IdentityType(ib.getType());
				identityTypes.put(ib.getType(), ib);
				identityTypesL.add(it);
				identityTypes2.put(ib.getId(), it);
			}
		} catch (PersistenceException e)
		{
			log.error("DB error: getting types. SQL error is: " + e);
			throw new InternalException("Can't load identity types.");
		} finally
		{
			db.releaseSqlSession(sqlMap);
		}
	}
	
	public IdentityType getIdentityType4Id(int id)
	{
		return identityTypes2.get(id);
	}

	public List<IdentityType> getIdentityTypes()
	{
		return identityTypesL;
	}
	
	public int getIdentityTypeId(String name) throws UnsupportedTypeException
	{
		IdentityTypeBean b = identityTypes.get(name);
		if (b == null)
			throw new UnsupportedTypeException();
		return b.getId();
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/db/DBIdentityTypes.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Nov 30, 2009
 * Author: T. Rekawek <newton@mat.uni.torun.pl>
 */

package pl.edu.icm.unicore.uvos.db;

import java.util.Hashtable;
import java.util.List;
import java.util.Vector;

import org.apache.ibatis.exceptions.PersistenceException;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.IdentityType;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.UnsupportedTypeException;
import pl.edu.icm.unicore.uvos.model.IdentityTypeBean;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;

/**
 * DB operations related to identity types.
 * @author T. Rekawek
 */
public class DBIdentityTypes
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, DBIdentityTypes.class);
	private Hashtable<String, IdentityTypeBean> identityTypes;
	private Hashtable<Integer, IdentityType> identityTypes2;
	private Vector<IdentityType> identityTypesL;
	
	public DBIdentityTypes(DB db) throws InternalException
	{
		SqlSession sqlMap = db.getSqlSession();

		identityTypes = new Hashtable<String, IdentityTypeBean>();
		identityTypes2 = new Hashtable<Integer, IdentityType>();
		identityTypesL = new Vector<IdentityType>();
		try
		{
			List<?> idTypes = sqlMap.selectList("getAllIdentityTypes");
			for (Object o: idTypes)
			{
				IdentityTypeBean ib = (IdentityTypeBean)o;
				IdentityType it = new IdentityType(ib.getType());
				identityTypes.put(ib.getType(), ib);
				identityTypesL.add(it);
				identityTypes2.put(ib.getId(), it);
			}
		} catch (PersistenceException e)
		{
			log.error("DB error: getting types. SQL error is: " + e);
			throw new InternalException("Can't load identity types.");
		} finally
		{
			db.releaseSqlSession(sqlMap);
		}
	}
	
	public IdentityType getIdentityType4Id(int id)
	{
		return identityTypes2.get(id);
	}

	public List<IdentityType> getIdentityTypes()
	{
		return identityTypesL;
	}
	
	public int getIdentityTypeId(String name) throws UnsupportedTypeException
	{
		IdentityTypeBean b = identityTypes.get(name);
		if (b == null)
			throw new UnsupportedTypeException();
		return b.getId();
	}
}
